@@ -11,13 +11,13 @@ import asyncio
 
 import edge_tts
 
+TEXT = "Hello World!"
+VOICE = "en-GB-SoniaNeural"
+OUTPUT_FILE = "test.mp3"
+WEBVTT_FILE = "test.vtt"
 
-async def main() -> None:
-    TEXT = "Hello World!"
-    VOICE = "en-GB-SoniaNeural"
-    OUTPUT_FILE = "test.mp3"
-    WEBVTT_FILE = "test.vtt"
 
+async def _main() -> None:
     communicate = edge_tts.Communicate(TEXT, VOICE)
     submaker = edge_tts.SubMaker()
     with open(OUTPUT_FILE, "wb") as file:
@@ -32,4 +32,4 @@ async def main() -> None:
 
 
 if __name__ == "__main__":
-    asyncio.get_event_loop().run_until_complete(main())
+    asyncio.get_event_loop().run_until_complete(_main())
